@@ -36,24 +36,20 @@ class NvidiaDriver(XorgDriverHandler):
                 'that requires 3D acceleration, such as some games.'))
 
         self._recommended = None
+        self._do_rebind = False
         
     def id(self):
         '''Return an unique identifier of the handler.'''
 
         if self.package:
-            i = 'xorg:' + self.module + '-' + self.package.split('-')[-1]
+            self.version = self.package.split('-')[-1]
+            i = 'xorg:' + self.module + '-' + self.version
         else:
             i = 'xorg:' + self.module
         if self.driver_vendor:
             i += ':' + self.driver_vendor.replace(' ', '_')
         return i
 
-    def name(self):
-        name = XorgDriverHandler.name(self)
-        if self.package:
-            name += ' (' + _('version %s') % self.package.split('-')[-1] + ')'
-        return name
-
     def enable_config_hook(self):
         # set DefaultDepth to 24; X.org does not work otherwise
         if len(self.xorg_conf.globaldict['Screen']) == 0:
@@ -62,11 +58,11 @@ class NvidiaDriver(XorgDriverHandler):
         self.xorg_conf.addOption('Screen', 'DefaultDepth', '24', position=0, prefix='')
 
         # version 96 needs AddARGBGLXVisuals
-        if self.package and self.package.endswith('-96'):
+        if self.version == '96':
             self.xorg_conf.addOption('Screen', 'AddARGBGLXVisuals', 'True', optiontype='Option', position=0)
 
         # version 71 needs a couple of extra driver options
-        if self.package and self.package.endswith('-71'):
+        if self.version == '71':
             for opt in ('AllowGLXWithComposite', 'UseEdidFreqs'):
                 self.xorg_conf.addOption('Device', opt, 'True', optiontype='Option', position=0)
         
