@@ -6,17 +6,13 @@
 
 import jockey.handlers
 
-class DemoPkgHandler(jockey.handlers.DriverPackageHandler):
-    def __init__(self, ui):
-        jockey.handlers.DriverPackageHandler.__init__(self, ui,
-            'pmount')
+class DemoPkgHandler(jockey.handlers.Handler):
+    def __init__(self, backend):
+        jockey.handlers.Handler.__init__(self, backend, None)
+        self.package = 'pmount'
 
     def available(self):
         return True
 
     def used(self):
         return self.enabled()
-
-    def ui_category(self):
-        return self.ui._('Test driver')
-
