@@ -49,6 +49,10 @@ class Handler:
         a multi-line description can be given, too. Every handler gets a
         reference to the currently used Backend so that it can request
         installation of packages and other system changes.
+
+        By default, available handlers are announced in
+        AbstractUI.check(). If you want to have a handler which is
+        available, but not announced that way, set self.annonuce to False.
         '''
         self._hwids = [] # covered HardwareIDs
         self._changed = False
@@ -58,6 +62,7 @@ class Handler:
         self._description = description
         self._rationale = rationale
         self.license = None
+        self.announce = True
 
         # the following properties are not specified in the ctor, since they
         # might be changed after instantiation;
@@ -225,6 +230,8 @@ class Handler:
             if not OSLib.inst.package_installed(self.package):
                 # do not touch _changed if package failed to install
                 return True
+        # packages might install/remove blacklists
+        OSLib.inst._load_module_blacklist()
         self._changed = True
         return True
 
@@ -382,6 +389,7 @@ class KernelModuleHandler(Handler):
             assert self._modinfo, 'kernel module %s exists' % self.module
             name = '\n'.join(self._modinfo.get('description', [self.module]))
         Handler.__init__(self, backend, name, description, rationale)
+        self._do_rebind = True
 
     def id(self):
         '''Return an unique identifier of the handler.'''
@@ -429,6 +437,12 @@ class KernelModuleHandler(Handler):
         This defaults to None, because we usually want to delegate this to the
         driver db. Subclasses are welcome to override this, of course.
         '''
+        # check for unavailable package, etc.
+        try:
+            if Handler.available(self) == False:
+                return False
+        except NotImplementedError:
+            pass
         return None
 
     def enable(self):
@@ -441,7 +455,8 @@ class KernelModuleHandler(Handler):
         subprocess.call([OSLib.inst.modprobe_path, self.module])
         self._modinfo = detection.get_modinfo(self.module)
         self.read_loaded_modules()
-        return self.rebind(self.module) # TODO: is this always wanted?
+        if self._do_rebind:
+            return self.rebind(self.module)
 
     def disable(self):
         '''Prevent the OS from using it even if the hardware is available.
@@ -477,8 +492,12 @@ class KernelModuleHandler(Handler):
                     continue
                 try:
                     logging.debug('unbind/rebind on driver %s: device %s', driver_path, device)
-                    open(os.path.join(driver_path, 'unbind'), 'w').write(device)
-                    open(os.path.join(driver_path, 'bind'), 'w').write(device)
+                    f = open(os.path.join(driver_path, 'unbind'), 'w')
+                    f.write(device)
+                    f.close()
+                    f = open(os.path.join(driver_path, 'bind'), 'w')
+                    f.write(device)
+                    f.close()
                 except IOError:
                     logging.warning('unbind/rebind for device %s on driver %s failed', 
                         device, driver_path, exc_info=True)
