@@ -50,7 +50,7 @@ class OSLib:
 
         # path to a modprobe.d configuration file where kernel modules are
         # enabled and disabled with blacklisting
-        self.module_blacklist_file = '/etc/modprobe.d/blacklist-local'
+        self.module_blacklist_file = '/etc/modprobe.d/blacklist-local.conf'
 
         # path to modinfo binary
         self.modinfo_path = '/sbin/modinfo'
@@ -89,14 +89,17 @@ class OSLib:
     def is_package_free(self, package):
         '''Return if given package is free software.'''
 
-        pkcon = subprocess.Popen(['pkcon', 'get-details', package],
+        pkcon = subprocess.Popen(['pkcon', '--filter=newest', 
+            'get-details', package], stdin=subprocess.PIPE, 
             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        out = pkcon.communicate()[0]
+        # we send an "1" to select package if several versions 
+        # are available (--filter is broken in at least Fedora 10)
+        out = pkcon.communicate('1\n')[0]
         m = re.search("^\s*license:\s*'?(.*)'?$", out, re.M)
         if m:
             # TODO: check more licenses here
-            return m.group(1).lower() in ('free', 'gpl', 'gplv2', 'gplv3',
-                'bsd', 'mpl')
+            return m.group(1).lower().startswith('gpl') or \
+                m.group(1).lower() in ('free', 'bsd', 'mpl')
         else:
             raise ValueError, 'package %s does not exist' % package
 
@@ -113,9 +116,12 @@ class OSLib:
         
         This should raise a ValueError if the package is not available.
         '''
-        pkcon = subprocess.Popen(['pkcon', 'get-details', package],
+        pkcon = subprocess.Popen(['pkcon', '--filter=newest', 
+            'get-details', package], stdin=subprocess.PIPE, 
             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        out = pkcon.communicate()[0]
+        # we send an "1" to select package if several versions 
+        # are available (--filter is broken in at least Fedora 10)
+        out = pkcon.communicate('1\n')[0]
         m = re.search("^\s*description:\s*'?(.*?)'?$", out, re.M | re.S)
         if m:
             # TODO: short description (not accessible with pkcon)
@@ -128,18 +134,17 @@ class OSLib:
         
         This should raise a ValueError if the package is not installed.
         '''
-        pkcon = subprocess.Popen(['pkcon', 'get-files', package],
+        pkcon = subprocess.Popen(['pkcon', '--filter=installed', 
+            'get-files', package], stdin=subprocess.PIPE, 
             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        out = pkcon.communicate()[0]
+        # we send an "1" to select package if several versions 
+        # are available (--filter is broken in at least Fedora 10)
+        out = pkcon.communicate('1\n')[0]
         if pkcon.returncode == 0 and '\n  ' in out:
             return [l.strip() for l in out.splitlines() if l.startswith('  ')]
         else:
             raise ValueError, 'package %s is not installed' % package
 
-    # 
-    # The following functions MUST be implemented by distributors
-    #
-
     def install_package(self, package, progress_cb):
         '''Install the given package.
 
@@ -155,8 +160,37 @@ class OSLib:
 
         Any installation failure should be raised as a SystemError.
         '''
-        raise NotImplementedError, 'subclasses need to implement this'
+        pkcon = subprocess.Popen(['pkcon', 'install', '-v', package],
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
+        re_progress = re.compile('progress-changed (\d+), (\d+),')
+
+        phase = None
+        err = ''
+        fail = False
+        while pkcon.poll() == None:
+            line = pkcon.stdout.readline()
+            if line == '':
+                break
+            if fail:
+                err += line
+            if 'status-changed download' in line:
+                phase = 'download'
+            elif 'status-changed commit' in line:
+                phase = 'install'
+            elif progress_cb and 'progress-changed' in line:
+                m = re_progress.search(line)
+                if m and phase:
+                    progress_cb(phase, int(m.group(1)), int(m.group(2)))
+                else:
+                    progress_cb(phase or 'download', -1, -1)
+            elif 'WARNING' in line:
+                fail = True
+
+        err += pkcon.stderr.read()
+        if pkcon.wait() != 0 or not self.package_installed(package):
+            raise SystemError, 'package %s failed to install: %s' % (package, err) 
+            
     def remove_package(self, package, progress_cb):
         '''Uninstall the given package.
 
@@ -170,20 +204,54 @@ class OSLib:
 
         Any removal failure should be raised as a SystemError.
         '''
-        raise NotImplementedError, 'subclasses need to implement this'
+        pkcon = subprocess.Popen(['pkcon', 'remove', '-v', package],
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+        re_progress = re.compile('progress-changed (\d+), (\d+),')
+
+        have_progress = False
+        err = ''
+        fail = False
+        while pkcon.poll() == None:
+            line = pkcon.stdout.readline()
+            if line == '':
+                break
+            if fail:
+                err += line
+            if 'status-changed remove' in line:
+                have_progress = True
+            elif progress_cb and 'progress-changed' in line:
+                m = re_progress.search(line)
+                if m and have_progress:
+                    progress_cb(int(m.group(1)), int(m.group(2)))
+                else:
+                    progress_cb(-1, -1)
+            elif 'WARNING' in line:
+                fail = True
+
+        err += pkcon.stderr.read()
+        if pkcon.wait() != 0 or self.package_installed(package):
+            raise SystemError, 'package %s failed to remove: %s' % (package, err) 
 
     def packaging_system(self):
         '''Return packaging system.
 
-        Currently defined values: apt
+        Currently defined values: apt, yum
         '''
-        # apt
         if os.path.exists('/etc/apt/sources.list') or os.path.exists(
             '/etc/apt/sources.list.d'):
             return 'apt'
+        elif os.path.exists('/etc/yum.conf'):
+            return 'yum'
 
         raise NotImplementedError, 'local packaging system is unknown'
 
+    # 
+    # The following functions MUST be implemented by distributors
+    # Note that apt and yum PackageKit backends currently do not implement
+    # RepoSetData(), so those need to remain package system specific
+    #
+
     def add_repository(self, repository):
         '''Add a repository.
 
@@ -345,10 +413,10 @@ class OSLib:
         This defaults to reading the values from lsb_release.
         '''
         p = subprocess.Popen(['lsb_release', '-si'], stdout=subprocess.PIPE,
-            stderr=subprocess.STDOUT, close_fds=True)
+            stderr=subprocess.PIPE, close_fds=True)
         self.os_vendor = p.communicate()[0].strip()
         p = subprocess.Popen(['lsb_release', '-sr'], stdout=subprocess.PIPE,
-            stderr=subprocess.STDOUT, close_fds=True)
+            stderr=subprocess.PIPE, close_fds=True)
         self.os_version = p.communicate()[0].strip()
         assert p.returncode == 0
 
