@@ -28,7 +28,9 @@ import dbus.service
 import dbus.mainloop.glib
 
 from oslib import OSLib
-from backend import UnknownHandlerException, PermissionDeniedByPolicy, BackendCrashError, polkit_auth_wrapper, dbus_sync_call_signal_wrapper, Backend, DBUS_BUS_NAME
+from backend import UnknownHandlerException, PermissionDeniedByPolicy, \
+    BackendCrashError, convert_dbus_exceptions, \
+    dbus_sync_call_signal_wrapper, Backend, DBUS_BUS_NAME
 
 def bool(str):
     '''Convert backend encoding of a boolean to a real boolean.'''
@@ -204,11 +206,9 @@ class AbstractUI(dbus.service.Object):
             # %(os)s stands for the OS name. Prefix it or suffix it,
             # but do not replace it.
             'Proprietary drivers do not have public source code that %(os)s '
-            'developers are free to modify. They represent a risk to you '
-            'because they are only available on the types of computer chosen by '
-            'the manufacturer, and security updates to them depend solely on the '
-            'responsiveness of the manufacturer. %(os)s cannot fix or improve '
-            'these drivers.') % {'os': OSLib.inst.os_vendor}
+            'developers are free to modify. Security updates and corrections '
+            'depend solely on the responsiveness of the manufacturer. '
+            '%(os)s cannot fix or improve these drivers.') % {'os': OSLib.inst.os_vendor}
         else:
             subtext = ''
 
@@ -231,6 +231,8 @@ class AbstractUI(dbus.service.Object):
         '''
         result = handler_info['name']
         result = self._(result)
+        if 'version' in handler_info:
+            result += ' (%s)' % (self._('version %s') % handler_info['version'])
         if bool(handler_info['recommended']):
             result += ' [%s]' % self.string_recommended
         return result
@@ -257,7 +259,7 @@ class AbstractUI(dbus.service.Object):
                 'certification_label': '', 'button_toggle_label': None,
             }
 
-        info = polkit_auth_wrapper(self.backend().handler_info, handler_id)
+        info = self.backend().handler_info(handler_id)
 
         result = {
             'name': self.get_ui_driver_name(info),
@@ -372,7 +374,7 @@ class AbstractUI(dbus.service.Object):
         '''
         # first, modes without GUI
         if self.argv_options.update_db:
-            polkit_auth_wrapper(self.backend().update_driverdb)
+            self.backend().update_driverdb()
             return 0
         elif self.argv_options.list:
             self.list()
@@ -438,16 +440,20 @@ class AbstractUI(dbus.service.Object):
         Return True if any new driver is available which is not yet enabled.
         '''
         try:
-            (new_used, new_avail) = polkit_auth_wrapper(
-                self.backend().new_used_available, self.argv_options.mode)
+            (new_used, new_avail) = convert_dbus_exceptions(
+                    self.backend().new_used_available, self.argv_options.mode)
         except PermissionDeniedByPolicy:
             self.error_msg(self.string_unprivileged)
             return False
 
-        # any new restricted drivers?
+        # any new restricted drivers? also throw out the non-announced ones
         restricted_available = False
-        for h_id in new_avail:
-            if not bool(self.backend().handler_info(h_id)['free']):
+        for h_id in set(new_avail): # create copy
+            info = self.backend().handler_info(h_id)
+            if not bool(info['announce']):
+                new_avail.remove(h_id)
+                continue
+            if not bool(info['free']):
                 restricted_available = True
                 break
 
@@ -537,7 +543,7 @@ class AbstractUI(dbus.service.Object):
         refreshed.
         '''
         try:
-            i = polkit_auth_wrapper(self.backend().handler_info, handler_id)
+            i = convert_dbus_exceptions(self.backend().handler_info, handler_id)
         except UnknownHandlerException:
             self.error_msg('%s: %s' % (self.string_unknown_driver, handler_id))
             self.error_msg(self._('Use --list to see available drivers'))
@@ -585,8 +591,8 @@ class AbstractUI(dbus.service.Object):
             if gui:
                 try:
                     self._install_progress_shown = False
-                    polkit_auth_wrapper(dbus_sync_call_signal_wrapper, 
-                        self.backend(), 'set_enabled',
+                    convert_dbus_exceptions(dbus_sync_call_signal_wrapper, self.backend(),
+                        'set_enabled',
                         {'install_progress': self._install_progress_handler, 
                          'remove_progress': self._remove_progress_handler}, 
                         handler_id, enable)
@@ -594,7 +600,8 @@ class AbstractUI(dbus.service.Object):
                     if self._install_progress_shown:
                         self.ui_progress_finish()
             else:
-                polkit_auth_wrapper(self.backend().set_enabled, handler_id, enable)
+                convert_dbus_exceptions(dbus_sync_call_signal_wrapper,
+                        self.backend(), 'set_enabled', {}, handler_id, enable)
         except PermissionDeniedByPolicy:
             self.error_message('', self.string_unprivileged)
             return False
@@ -605,7 +612,7 @@ class AbstractUI(dbus.service.Object):
                 self._('Trying to recover by restarting backend.')))
             return False
         except SystemError, e:
-            self.error_message('', e.message.splitlines()[-1])
+            self.error_message('', str(e).strip().splitlines()[-1])
             return False
 
         newstate = bool(self.backend().handler_info(handler_id)['enabled'])
@@ -840,8 +847,8 @@ class AbstractUI(dbus.service.Object):
     def ui_init(self):
         '''Initialize UI.
 
-        This should load the GUI components, such as glade files, but not show
-        the main window yet; that is done by ui_show_main().
+        This should load the GUI components, such as GtkBuilder files, but not
+        show the main window yet; that is done by ui_show_main().
         '''
         raise NotImplementedError, 'subclasses need to implement this'
         
