@@ -683,7 +683,7 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
             print >> sys.stderr, '[skipped, no default route] ',
             return
 
-        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP LaserJet 3020')
+        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP DesignJet 3500CP')
         db = jockey.detection.OpenPrintingDriverDB()
         orig_pkgsys = OSLib.inst.packaging_system
         try:
@@ -715,7 +715,7 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
 
         backend = jockey.backend.Backend()
         backend.hardware = set([HardwareID('printer_deviceid',
-            'MFG:Hewlett-Packard;MDL:HP LaserJet 3020')])
+            'MFG:Hewlett-Packard;MDL:HP DesignJet 3500CP')])
         backend.driver_dbs.append(jockey.detection.OpenPrintingDriverDB())
         orig_pkgsys = OSLib.inst.packaging_system
         try:
@@ -743,7 +743,7 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
             print >> sys.stderr, '[skipped, no default route] ',
             return
 
-        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP LaserJet 3020')
+        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP DesignJet 3500CP')
         db = jockey.detection.OpenPrintingDriverDB()
 
         orig_pkgsys = OSLib.inst.packaging_system
@@ -774,7 +774,7 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
             print >> sys.stderr, '[skipped, no default route] ',
             return
 
-        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP LaserJet 3020')
+        prn = HardwareID('printer_deviceid', 'MFG:Hewlett-Packard;MDL:HP DesignJet 3500CP')
         db = jockey.detection.OpenPrintingDriverDB()
         orig_pkgsys = OSLib.inst.packaging_system
         try:
