@@ -88,6 +88,7 @@ class HandlerTest(sandbox.LogTestCase):
         self.assertEqual(h.rationale(), None)
         self.failIf(h.changed())
         self.assertEqual(h.can_change(), None)
+        self.assertEqual(h.announce, True)
 
         # description and rationale
         h = jockey.handlers.Handler(self.backend, 'shiny driver', 
@@ -235,6 +236,10 @@ class HandlerTest(sandbox.LogTestCase):
         h.driver_vendor = 'Foo Bar'
         self.assertEqual(h.id(), 'kmod:vanilla3d:Foo_Bar')
 
+        # unavailable package
+        h.package = 'nonexisting'
+        self.assertEqual(h.available(), False)
+
     def test_kmod_package_used(self):
         '''KernelModuleHandler: used() with third-party packages'''
 
