@@ -387,13 +387,13 @@ class UITest(sandbox.LogTestCase):
         self.failIf('Restricted' in ui.main_window_title())
         (h, s) = ui.main_window_text()
         self.assert_('No proprietary drivers are in use' in h)
-        self.assert_('risk' in s)
+        self.assert_('cannot fix or improve' in s)
 
         # enable mint
         ui.backend().set_enabled('kmod:mint', True)
         (h, s) = ui.main_window_text()
         self.assert_('Proprietary drivers are being used' in h)
-        self.assert_('risk' in s)
+        self.assert_('cannot fix or improve' in s)
 
     def test_mode_free(self):
         '''calling with --mode free'''
@@ -438,7 +438,7 @@ class UITest(sandbox.LogTestCase):
 
         (h, s) = ui.main_window_text()
         self.assert_('No proprietary drivers are in use' in h, h)
-        self.assert_('risk' in s)
+        self.assert_('cannot fix or improve' in s)
 
     def test_check(self):
         '''calling with --check'''
@@ -473,6 +473,17 @@ class UITest(sandbox.LogTestCase):
             self.assert_(ui.main_loop_active)
             os.unlink(OSLib.inst.check_cache)
 
+            # non-announced handlers do not cause notifications
+            ui = sandbox.TestUI()
+            for h in ui.backend().available():
+                ui.backend().handlers[h].announce = False
+            self.assertEqual(ui.run(), 1)
+
+            self.assertRaises(IndexError, ui.pop_error)
+            self.assertRaises(IndexError, ui.pop_notification)
+            self.failIf(ui.main_loop_active)
+            os.unlink(OSLib.inst.check_cache)
+
             # new free drivers which are not enabled -> free notification
             sys.argv = ['ui-test', '--check', '-m', 'free']
             ui = sandbox.TestUI()
